<?php
/**
 *
 * Copyright © 2015 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Blackbird\ContentManager\Controller\Adminhtml\ContentType;

class MassDelete extends \Blackbird\ContentManager\Controller\Adminhtml\ContentType
{
    /**
     * Field id
     */
    const ID_FIELD = \Blackbird\ContentManager\Api\Data\ContentTypeInterface::ID;
    
    /**
     * Mass Delete action
     * 
     * @return \Magento\Backend\Model\View\Result\Redirect
     */
    public function execute()
    {
        $this->_initAction();
        
        $ids = $this->getRequest()->getParam('id');
        $contentTypeCollection = $this->_contentTypeCollectionFactory->create();
        
        if (is_array($ids)) {
            $contentTypeCollection->addFieldToFilter(static::ID_FIELD, ['in' => $ids]);
            $records = 0;
            
            // Delete content types
            foreach ($contentTypeCollection as $contentType) {
                try {
                    $contentType->delete();
                    $records++;
                } catch (\Exception $e) {
                    $this->messageManager->addException($e, __('Something went wrong while deleting the content type: %1', $e->getMessage()));
                }
            }
            
            $this->messageManager->addSuccess(__('A total of %1 record(s) have been deleted.', $records));
            
            // Flush backend main menu cache
            $this->flushBackendMainMenuCache();
            
        } else {
            $this->messageManager->addError(__('Please select item(s).'));
        }
        
        return $this->resultRedirect->setPath('*/*/');
    }

    /**
     * Returns result of current user permission check on resource and privilege
     *
     * @return bool
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Blackbird_ContentManager::contenttype_delete');
    }
}
